@@ -9,17 +9,12 @@ class BaseJavaClass(object):
 
         if self.javaClassName is None or self.javaClassName == "":
             self.javaClassName = str(self.javaClass.getClass().getName())
-        self.init()
-
-    def init(self):
-        raise Exception('You have to implement the method init!')
 
     def getJavaClass(self):
         return self.javaClass
 
     def setJavaClass(self, javaClass):
         self.javaClass = javaClass
-        self.init()
 
     def getJavaClassName(self):
         return self.javaClassName
@@ -27,9 +22,6 @@ class BaseJavaClass(object):
     def isNull(self):
         return self.javaClass.isNull()
 
-    def printJavaClassName(self):
-        print("Java class name => \'" + self.javaClassName + "\'")
-
 
 class Rectangle(BaseJavaClass):
     """!
@@ -38,9 +30,6 @@ class Rectangle(BaseJavaClass):
     in the coordinate space, its width, and its height.
     """
 
-    def init(self):
-        pass
-
     javaClassName = "java.awt.Rectangle"
 
     def __init__(self, x, y, width, height):
@@ -179,9 +168,6 @@ class Point(BaseJavaClass):
         point.javaClass = arg
         return point
 
-    def init(self):
-        pass
-
     def getX(self):
         """!
         The X coordinate of this <code>Point</code>.
